﻿
local SpeakinSpell = LibStub("AceAddon-3.0"):GetAddon("SpeakinSpell")
local L	= LibStub("AceLocale-3.0"):GetLocale("SpeakinSpell", false)

SpeakinSpell:PrintLoading("SpeakinSpell.lua")

-------------------------------------------------------------------------------
-- GENERAL INITIALIZATION AND MAIN ENTRY POINTS
-------------------------------------------------------------------------------


function SpeakinSpell:ResetToDefaults(FrameName) --TODOFUTURE: reset only the current frame's defaults (optionally)
	table.wipe( self:GetActiveEventTable() )
	
	-- stop networking
	self:Network_Disable()
	
	-- update/reset runtime data state
	self:InitRuntimeData()
	
	-- reset the default templates to restore previously redundant content
	self:Templates_Release()
	
	-- copy defaults into current settings using class-specific defaults
	self:InitDefaultSavedData()
	
	-- if the options GUI is showing right now, we need to refresh it to make it show the new data
	self:RefreshAllFrames()
	
	-- resume networking
	self:Network_Init()
	
	self:Print(L["Default settings restored"])
end




function SpeakinSpell:OnInitialize()
	local funcname = "OnInitialize"
	self:DebugMsg(funcname, "starting")

    -- Called when the addon is loaded
    -- Variables have not yet been loaded

	self:InitRuntimeData()			-- initialize self.RuntimeData.Stuff
	self:RegisterAllEvents()		-- includes registering for VARIABLES_LOADED event -> OnVariablesLoaded
	self:RegisterChatCommands()		-- setup /ss stuff
	self:Templates_OnInitialize()	-- initialize Templates info for default speeches
	
	-- NOTE: the rest of the initialization does not occur until OnVariablesLoaded below
	self:DebugMsg(funcname, "done")
end


-- after OnInitialize, the main initialization waits until the saved variables areloaded
function SpeakinSpell:OnVariablesLoaded()
	local funcname = "OnVariablesLoaded"
	self:DebugMsg(funcname, "starting")

	-- SpeakinSpellSavedData and ForAll will always exist
	-- they'll be empty if no saved data was actually loaded (fresh install or reset)
	
	if	SpeakinSpellSavedData.Version or		-- current test for existance of saved data for versions >= 3.2.2.17
		SpeakinSpellSavedData.EventTable or		-- old data location from before v3.2.2.17
		SpeakinSpellSavedData.SpellTable then	-- old name from v3.1.2.04 and earlier
		-- If the format of the saved data has changed due to upgrading to a newer version
		-- then fix the old saved data for compatibility - also may fix corrupted data, etc.
		self:ValidateAllSavedData()
		self:Templates_OnVariablesLoaded()	-- initialize Templates info for default speeches
	else
		-- new user: load defaults
		self:DebugMsg(funcname, "EventTable does not exist, using defaults")
		self:InitDefaultSavedData() --also calls ValidateAllSavedData
	end	

	-- set up the Options GUI
	-- NOTE: we want to have the Saved Data before we do this
	self:CreateGUI()
	
	-- Print done loading
	if SpeakinSpellSavedData.ShowVersionAtLogin then
		self:Print( string.format(L["Loaded version %s"], self.CURRENT_VERSION) )
	end

	-- trigger a Speech Event for loading
	local DetectedEventStub = {
		-- event descriptors
		name = L["SpeakinSpell Loaded"],
		type = "EVENT",
		-- event-specific data for substitutions
		caster = UnitName("player"),
		target = UnitName("player"),
	}
	self:OnSpeechEvent( DetectedEventStub ) 
	
	-- start network communications, if applicable
	self:Network_Init()
	
	-- start watching for rez events from LibResComm 
	-- this might immediately start wanting to use the speeches
	--self:Rez_Init()

	-- Done
	self:DebugMsg(funcname, "done")
end


function SpeakinSpell:OnEnable()
	-- Called when the addon is enabled
	-- self:RegisterAllEvents() -- did this OnInitialize
end


function SpeakinSpell:OnDisable()
    -- Called when the addon is disabled
	-- we don't need to do anything here
end

